==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/Ibukiho.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.data.ModTags;
import cc.thonly.reverie_dreams.item.base.SwordItem;
import net.minecraft.class_1268;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3222;
import net.minecraft.class_3489;
import net.minecraft.class_9886;

public class Ibukiho extends SwordItem {
    public static final class_9886 IBUKIHO = new class_9886(ModTags.BlockTypeTag.EMPTY, 1561, 8.0f, 5.5f, 10, class_3489.field_38837);

    public Ibukiho(float attackDamage, float attackSpeed, class_1793 settings) {
        super(IBUKIHO,
                attackDamage,
                attackSpeed,
                settings
        );
    }

    @Override
    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        class_1799 copy = stack.method_7972();
        class_1268 activeHand = user.method_6058();
        if (copy.method_7963() && user instanceof class_3222 player && !player.method_56992()) {
            copy.method_7970(10, user, class_1304.field_6173);
        }
        user.method_6122(activeHand, copy);
        class_1293 strength = new class_1293(class_1294.field_5910, 60 * 20);
        class_1293 speed = new class_1293(class_1294.field_5904, 60 * 20);
        class_1293 jumpBoost = new class_1293(class_1294.field_5913, 60 * 20);
        class_1293 nausea = new class_1293(class_1294.field_5916, 60 * 20);
        user.method_6092(strength);
        user.method_6092(speed);
        user.method_6092(jumpBoost);
        user.method_6092(nausea);
        return super.method_7861(stack, world, user);
    }
}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/Ibukiho.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.reverie_dreams.registry.tag.RDBlockTags;
import net.minecraft.class_1268;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3222;
import net.minecraft.class_3489;
import net.minecraft.class_9886;
import cc.thonly.reverie_dreams.item.base.SwordItem;

public class Ibukiho extends SwordItem {
    public static final class_9886 IBUKIHO = new class_9886(RDBlockTags.EMPTY, 1561, 8.0f, 5.5f, 10, class_3489.field_38837);

    public Ibukiho(float attackDamage, float attackSpeed, class_1793 settings) {
        super(IBUKIHO,
                attackDamage,
                attackSpeed,
                settings
        );
    }

    @Override
    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        class_1799 copy = stack.method_7972();
        class_1268 activeHand = user.method_6058();
        if (copy.method_7963() && user instanceof class_3222 player && !player.method_56992()) {
            copy.method_7970(10, user, class_1304.field_6173);
        }
        user.method_6122(activeHand, copy);
        class_1293 strength = new class_1293(class_1294.field_5910, 60 * 20);
        class_1293 speed = new class_1293(class_1294.field_5904, 60 * 20);
        class_1293 jumpBoost = new class_1293(class_1294.field_5913, 60 * 20);
        class_1293 nausea = new class_1293(class_1294.field_5916, 60 * 20);
        user.method_6092(strength);
        user.method_6092(speed);
        user.method_6092(jumpBoost);
        user.method_6092(nausea);
        return super.method_7861(stack, world, user);
    }
}
